#
# spec file for package ghc-conduit
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name conduit
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.6.1
Release:        1.6
Summary:        Streaming data processing library
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mono-traversable-devel
BuildRequires:  ghc-mono-traversable-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-resourcet-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-core-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-safe-prof
BuildRequires:  ghc-silently-devel
BuildRequires:  ghc-silently-prof
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unliftio-prof
%endif

%description
`conduit` is a solution to the streaming data problem, allowing for production,
transformation, and consumption of streams of data in constant memory.
It is an alternative to lazy I/O which guarantees deterministic resource
handling.

For more information about conduit in general, and how this package in
particular fits into the ecosystem, see [the conduit
homepage](https://github.com/snoyberg/conduit#readme).

Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/conduit>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Feb 23 2025 Peter Simons <psimons@suse.com>
- Update conduit to version 1.3.6.1.
  [#]# 1.3.6.1
  * Forward compatibility with `-Wnoncanonical-monad-instances` becoming an error
* Mon Aug 26 2024 Peter Simons <psimons@suse.com>
- Update conduit to version 1.3.6.
  [#]# 1.3.6
  * Avoid dropping upstream items in `mergeSource` [#513](https://github.com/snoyberg/conduit/pull/513)
* Mon May 22 2023 Peter Simons <psimons@suse.com>
- Update conduit to version 1.3.5.
  [#]# 1.3.5
  * Add `groupOn`
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Oct 24 2022 Peter Simons <psimons@suse.com>
- Update conduit to version 1.3.4.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct  6 2022 Peter Simons <psimons@suse.com>
- Update conduit to version 1.3.4.3.
  [#]# 1.3.4.3
  * Fix space leak in `*>` [#496](https://github.com/snoyberg/conduit/issues/496) [#497](https://github.com/snoyberg/conduit/pull/497)
* Mon Sep 27 2021 psimons@suse.com
- Update conduit to version 1.3.4.2.
  [#]# 1.3.4.2
  * Fix GHC 9.2 build [#473](https://github.com/snoyberg/conduit/pull/473)
* Tue Mar  2 2021 psimons@suse.com
- Update conduit to version 1.3.4.1.
  [#]# 1.3.4.1
  * Library and tests compile and run with GHC 9.0.1 [#455](https://github.com/snoyberg/conduit/pull/455)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Nov 25 2020 psimons@suse.com
- Update conduit to version 1.3.4.
  [#]# 1.3.4
  * Add `foldWhile` [#453](https://github.com/snoyberg/conduit/issues/453) [#456](https://github.com/snoyberg/conduit/pull/456).
* Sat Oct 17 2020 psimons@suse.com
- Update conduit to version 1.3.3.
  [#]# 1.3.3
  * Add `uncons`, `unconsM`, `unconsEither`, `unconsEitherM`.
* Tue Sep  1 2020 psimons@suse.com
- Update conduit to version 1.3.2.1.
  [#]# 1.3.2.1
  * Fix isChunksForExactlyE [#445](https://github.com/snoyberg/conduit/issues/445) [#446](https://github.com/snoyberg/conduit/pull/446)
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update conduit to version 1.3.2.
  [#]# 1.3.2
  * Add `mapInputM` [#435](https://github.com/snoyberg/conduit/pull/435)
* Tue Dec 17 2019 psimons@suse.com
- Update conduit to version 1.3.1.2.
  [#]# 1.3.1.2
  * More eagerly emit groups in `chunksOf` [#427](https://github.com/snoyberg/conduit/pull/427)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Mar 13 2019 psimons@suse.com
- Update conduit to version 1.3.1.1.
  [#] ChangeLog for conduit
  [#]# 1.3.1.1
  * Use lower-case imports (better for cross-compilation) [#408](https://github.com/snoyberg/conduit/pull/408)
* Wed Oct 10 2018 psimons@suse.com
- Update conduit to version 1.3.1.
  [#]# 1.3.1
  * Add `MonadFail` instance for `ConduitT`.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update conduit to version 1.3.0.3.
  [#]# 1.3.0.3
  * Improve fusion framework rewrite rules
* Mon May 14 2018 psimons@suse.com
- Update conduit to version 1.3.0.2.
  * Replace `ReadMode` with `WriteMode` in `withSinkFile`
  * Test suite compatibility with GHC 8.4.1 [#358](https://github.com/snoyberg/conduit/issues/358)
  * Drop monad-control and exceptions in favor of unliftio
  * Drop mmorph dependency
  * Deprecate old type synonyms and operators
  * Drop finalizers from the library entirely
  * Much simpler
  * Less guarantees about prompt finalization
  * No more `yieldOr`, `addCleanup`
  * Replace the `Resumable` types with `SealedConduitT`
  * Add the `Conduit` and `Data.Conduit.Combinators` modules, stolen from
    `conduit-combinators`
  * Add `Semigroup` instances [#345](https://github.com/snoyberg/conduit/pull/345)
  * Fix `pass` in `ConduitM` `MonadWriter` instance
  * Add `exceptC`, `runExceptC` and `catchExceptC` to `Data.Conduit.Lift`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 1.2.11.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 1.2.10 with cabal2obs.
* Sun Apr  9 2017 psimons@suse.com
- Update to version 1.2.9.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.2.9 with cabal2obs.
* Sat Oct  1 2016 psimons@suse.com
- Update to version 1.2.8 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 1.2.7 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.6.6 revision 0 with cabal2obs.
* Sat May  7 2016 mimi.vx@gmail.com
- update to 1.2.6.6
  * Fix test suite compilation on older GHCs
  * In zipConduitApp, left bias not respected mixing monadic and non-monadic conduits
* Sat Mar 12 2016 mimi.vx@gmail.com
- update to 1.2.6.4
  * fix benchmark by adding typesignature
* Mon Mar  7 2016 mimi.vx@gmail.com
- update to 1.2.6.3
* Mon Feb 15 2016 mimi.vx@gmail.com
- update to 1.2.6.2
  * resourcet cannot be built with GHC 8
  * Remove upper bound on transformers
* Thu Dec 31 2015 mimi.vx@gmail.com
- update to 1.2.6.1
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 1.2.6
  * sourceToList
  * Canonicalise Monad instances
* Sun Oct 25 2015 mimi.vx@gmail.com
- update to 1.2.5.1
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 1.2.5
  * mapAccum and mapAccumM should be strict in their state
  * Some documentation improvements
* Wed Apr 22 2015 mimi.vx@gmail.com
- update to 1.2.4
  * [fuseBothMaybe](https://github.com/snoyberg/conduit/issues/199)
* Sun Feb  1 2015 mpluskal@suse.com
- Update to 1.2.3.1:
  + Refactoring into conduit and conduit-extra packages. Core
    functionality is now in conduit, whereas most common helper
    modules (including Text, Binary, Zlib, etc) are in
    conduit-extra. To upgrade to this version, there should only be
    import list and conduit file changes necessary.
  + Two performance
    optimizations added. (1) A stream fusion framework. This is a non-breaking
    change. (2) Codensity transform applied to the `ConduitM` datatype. This only
    affects users importing the `.Internal` module. Both changes are thoroughly
    described in the following to blog posts: [Speeding up
    conduit](https://www.fpcomplete.com/blog/2014/08/iap-speeding-up-conduit), and
    [conduit stream
    fusion](https://www.fpcomplete.com/blog/2014/08/conduit-stream-fusion).
  + Lots more stream fusion.
  + Expose `connect` and `fuse` as synonyms for `$$` and `=$=`, respectively.
* Sun Oct  6 2013 sbahling@suse.com
- Initial package - version 1.0.7.4
